/** \file Settings.cpp
*/

/* Copyright (C) 2008-2009 Tomasz Ostrowski <tomasz.o.ostrowski at gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.

 * Miniscope is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#pragma hdrstop

#include <IniFiles.hpp>
#include "Settings.h"

//---------------------------------------------------------------------------

#pragma package(smart_init)

bool Settings::Read(AnsiString asFileName)
{
	TIniFile *ini = NULL;
	try
	{
		ini = new TIniFile(asFileName);
		// main window startup position
		int maxX = GetSystemMetrics(SM_CXSCREEN);
		int maxY = GetSystemMetrics(SM_CYSCREEN);
		iWidth = ini->ReadInteger("GUI", "AppWidth", 550);
		iHeight = ini->ReadInteger("GUI", "AppHeight", 400);
		if (iWidth < 250 || iWidth > maxX + 20)
		{
			iWidth = 250;
		}
		if (iHeight < 200 || iHeight > maxY + 20)
		{
			iHeight = 200;
		}
		iPosX = ini->ReadInteger("GUI", "AppPositionX", 30);
		iPosY = ini->ReadInteger("GUI", "AppPositionY", 30);
		if (iPosX < 0)
			iPosX = 0;
		if (iPosY < 0)
			iPosY = 0;
		if (iPosX + iWidth > maxX)
			iPosX = maxX - iWidth;
		if (iPosY + iHeight > maxY)
			iPosY = maxY - iHeight;
		bAlwaysOnTop = ini->ReadBool("GUI", "AlwaysOnTop", false);
		bWindowMaximized = ini->ReadBool("GUI", "Maximized", false);
		iMaxUiLogLines = ini->ReadInteger("Application", "MaxUiLogLines", 1000);
		iDisplayRefreshFreq = ini->ReadInteger("Application", "DisplayRefreshFreq", 20);
		//iSendSuffix = ini->ReadInteger("Application", "SendSuffix", SENDSUFFIX_CRLF);
		asInputDeviceDllName = ini->ReadString("Application", "InputDeviceDllName", "");
		delete ini;
	}
	catch (...)
	{
		if (ini)
		{
			delete ini;
		}
		return false;
	}
	return true;
}

bool Settings::Write(AnsiString asFileName)
{
	TIniFile *ini = NULL;
	try
	{
		ini = new TIniFile(asFileName);
		ini->WriteInteger("GUI", "AppWidth", iWidth);
		ini->WriteInteger("GUI", "AppHeight", iHeight);
		ini->WriteInteger("GUI", "AppPositionX", iPosX);
		ini->WriteInteger("GUI", "AppPositionY", iPosY);
		ini->WriteBool("GUI", "AlwaysOnTop", bAlwaysOnTop);
		ini->WriteBool("GUI", "Maximized", bWindowMaximized);	
		ini->WriteInteger("Application", "MaxUiLogLines", iMaxUiLogLines);
		ini->WriteInteger("Application", "DisplayRefreshFreq", iDisplayRefreshFreq);
        ini->WriteString("Application", "InputDeviceDllName", asInputDeviceDllName);

		delete ini;
	}
	catch (...)
	{
		if (ini)
		{
			delete ini;
		}
		return false;
	}
	return true;

}
